@@ -44,3 +44,7 @@ def get_now_allfiles(path: str, suffix: list=None):
 
 def abs_file(filename):
     return os.path.abspath(os.path.join(os.getcwd(), filename))
+
+
+def root_file(filename):
+    return os.path.join(os.path.expanduser('~'), filename)
