@@ -41,3 +41,21 @@ def which(cmd):
                 return exe_file
     return None
 
+
+def echo(cmd):
+    """
+    Returns full path to a PATH.
+
+    Args:
+        cmd (str): Executable command to search for.
+
+    Returns:
+        (str) Full path to command. None if it is not found.
+
+    Example::
+
+        full_path_to_python = which("python")
+    """
+    
+    return os.getenv(cmd.replace('$', ''), None)
+
