@@ -20,6 +20,18 @@ def check_empty(config_dict):
 def get_new_point_dict(config_dict: dict, needed_config: list):
     new_dict = dict()
     for i in needed_config:
-        new_dict[i] = config_dict[i]
+        new_dict[i] = config_dict.get(i, None)
     
     return new_dict
+
+
+def get_db_name(username):
+    return username.split('@')[0].replace(',', '_')
+
+
+def get_task_name(username):
+    return "'%s_running'" % get_db_name(username)
+
+
+def get_user_config_name(username):
+    return '%s_config' % get_db_name(username)
\ No newline at end of file
