@@ -29,4 +29,19 @@ def recursive_basic_type(obj):
             return recursive_basic_type(eval(obj))
         if obj.startswith('(') and obj.endswith(')'):
             return recursive_basic_type(eval(obj))
-    return obj
\ No newline at end of file
+    return obj
+
+
+class AlkDict(dict):
+    
+    def alkget(self, name, value):
+        tmp = self.get(name, None)
+        if tmp is not None:
+            return tmp
+        else:
+            return value
+        
+        
+if __name__ == '__main__':
+    a = AlkDict({'a': None})
+    print(a.alkget('a', 'sdfsdf'))
